@@ -6,13 +6,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #' 
 #' @description Plot odds ratios (forest plots) of multiple fitted glm's with confidence intervalls in one plot.
 #' 
-#' @seealso \itemize{
-#'            \item \code{\link{sjp.glm}}
-#'            \item \code{\link{sjt.glm}}
-#'            \item \code{\link{sjp.lmm}}
-#'            }
-#' 
-#' @param ... One or more fitted glm-objects.
+#' @param ... One or more fitted glm-objects. May also be a \code{\link{list}}-object with 
+#'          fitted models, instead of separating each model with comma. See examples.
 #' @param title Diagram's title as string.
 #'          Example: \code{title=c("my title")}
 #' @param labelDependentVariables Labels of the dependent variables of all fitted models
@@ -27,7 +22,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #' @param axisLabels.y Labels of the predictor variables (independent vars, odds) that are used for labelling the
 #'          axis. Passed as vector of strings.
 #'          Example: \code{axisLabels.y=c("Label1", "Label2", "Label3")}
-#'          Note: If you use the \code{\link{read_spss}} function and the \code{\link{get_val_labels}} function, you receive a
+#'          Note: If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
 #'          \code{list} object with label strings. The labels may also be passed as list object. They will be coerced
 #'          to character vector automatically.
 #' @param showAxisLabels.y Whether odds names (predictor labels) should be shown or not.
@@ -89,31 +84,42 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #'          
 #' @examples
 #' # prepare dummy variables for binary logistic regression
-#' y1 <- ifelse(swiss$Fertility<median(swiss$Fertility), 0, 1)
-#' y2 <- ifelse(swiss$Infant.Mortality<median(swiss$Infant.Mortality), 0, 1)
+#' y1 <- ifelse(swiss$Fertility < median(swiss$Fertility), 0, 1)
+#' y2 <- ifelse(swiss$Infant.Mortality < median(swiss$Infant.Mortality), 0, 1)
 #' y3 <- ifelse(swiss$Agriculture<median(swiss$Agriculture), 0, 1)
 #' 
 #' # Now fit the models. Note that all models share the same predictors
 #' # and only differ in their dependent variable (y1, y2 and y3)
-#' fitOR1 <- glm(y1 ~ swiss$Education+swiss$Examination+swiss$Catholic,
-#'               family=binomial(link="logit"))
-#' fitOR2 <- glm(y2 ~ swiss$Education+swiss$Examination+swiss$Catholic,
-#'               family=binomial(link="logit"))
-#' fitOR3 <- glm(y3 ~ swiss$Education+swiss$Examination+swiss$Catholic,
-#'               family=binomial(link="logit"))
+#' fitOR1 <- glm(y1 ~ swiss$Education + swiss$Examination + swiss$Catholic,
+#'               family = binomial(link = "logit"))
+#' fitOR2 <- glm(y2 ~ swiss$Education + swiss$Examination + swiss$Catholic,
+#'               family = binomial(link = "logit"))
+#' fitOR3 <- glm(y3 ~ swiss$Education + swiss$Examination + swiss$Catholic,
+#'               family = binomial(link = "logit"))
 #' 
 #' # plot multiple models
-#' sjp.glmm(fitOR1, fitOR2, fitOR3, facet.grid=TRUE)
+#' sjp.glmm(fitOR1, fitOR2, fitOR3, facet.grid = TRUE)
 #' 
 #' # plot multiple models with legend labels and point shapes instead of value  labels
 #' sjp.glmm(fitOR1, fitOR2, fitOR3,
-#'          labelDependentVariables=c("Fertility", "Infant Mortality", "Agriculture"),
-#'          showValueLabels=FALSE,
-#'          showPValueLabels=FALSE,
-#'          usePShapes=TRUE,
-#'          nsAlpha=0.2)
+#'          labelDependentVariables = c("Fertility", 
+#'                                      "Infant Mortality", 
+#'                                      "Agriculture"),
+#'          showValueLabels = FALSE,
+#'          showPValueLabels = FALSE,
+#'          usePShapes = TRUE,
+#'          nsAlpha = 0.2)
+#' 
+#' # plot multiple models from nested lists parameter
+#' all.models <- list()
+#' all.models[[1]] <- fitOR1
+#' all.models[[2]] <- fitOR2
+#' all.models[[3]] <- fitOR3
+#' 
+#' sjp.glmm(all.models)
 #' 
 #' @import ggplot2
+#' @import sjmisc
 #' @export
 sjp.glmm <- function(..., 
                     title=NULL,
@@ -128,7 +134,7 @@ sjp.glmm <- function(...,
                     breakLabelsAt=25,
                     breakLegendAt=20,
                     gridBreaksAt=0.5,
-                    transformTicks=FALSE,
+                    transformTicks=TRUE,
                     geom.size=3,
                     geom.spacing=0.4,
                     geom.colors="Dark2",
@@ -150,6 +156,11 @@ sjp.glmm <- function(...,
   # --------------------------------------------------------
   input_list <- list(...)
   # --------------------------------------------------------
+  # check length. if we have a list of fitted model, 
+  # we need to "unlist" them
+  # --------------------------------------------------------
+  if (length(input_list) == 1 && class(input_list[[1]]) == "list") input_list <- lapply(input_list[[1]], function(x) x)
+  # --------------------------------------------------------
   # unlist labels
   # --------------------------------------------------------
   # unlist axis labels (predictors)
@@ -169,27 +180,20 @@ sjp.glmm <- function(...,
   # Prepare length of title and labels
   # ----------------------------
   # check length of diagram title and split longer string at into new lines
-  if (!is.null(title)) {
-    title <- word_wrap(title, breakTitleAt)
-  }
+  if (!is.null(title)) title <- sjmisc::word_wrap(title, breakTitleAt)
   # check length of x-axis title and split longer string at into new lines
   # every 50 chars
-  if (!is.null(axisTitle.x)) {
-    axisTitle.x <- word_wrap(axisTitle.x, breakTitleAt)
-  }
+  if (!is.null(axisTitle.x)) axisTitle.x <- sjmisc::word_wrap(axisTitle.x, breakTitleAt)
   # check length of dependent variables
   if (!is.null(labelDependentVariables)) {
-    labelDependentVariables <- word_wrap(labelDependentVariables, breakLegendAt)
-  }
-  else {
+    labelDependentVariables <- sjmisc::word_wrap(labelDependentVariables, breakLegendAt)
+  } else {
     # else if we have no labels of dependent variables supplied, use a 
     # default string (Model) for legend
     labelDependentVariables <- c(sprintf("%s %i", stringModel, 1:fitlength))
   }
   # check length of x-axis-labels and split longer strings at into new lines
-  if (!is.null(axisLabels.y)) {
-    axisLabels.y <- word_wrap(axisLabels.y, breakLabelsAt)
-  }
+  if (!is.null(axisLabels.y)) axisLabels.y <- sjmisc::word_wrap(axisLabels.y, breakLabelsAt)
   # ----------------------------
   # iterate all fitted models
   # ----------------------------
@@ -200,12 +204,12 @@ sjp.glmm <- function(...,
     # retrieve odds ratios (glm) 
     # ----------------------------
     # create data frame for ggplot
-    odds <- data.frame(cbind(exp(coef(fit)), exp(confint(fit))))
+    odds <- data.frame(exp(coef(fit)), exp(confint(fit)))
     # ----------------------------
     # print p-values in bar charts
     # ----------------------------
     # retrieve sigificance level of independent variables (p-values)
-    pv <- unname(coef(summary(fit))[,4])
+    pv <- unname(coef(summary(fit))[, 4])
     # for better readability, convert p-values to asterisks
     # with:
     # p < 0.001 = ***
@@ -240,26 +244,17 @@ sjp.glmm <- function(...,
     # copy p-values into data column
     # ----------------------------
     for (i in 1:length(pv)) {
-      if (pv[i]>=0.05) {
+      if (pv[i] >= 0.05) {
         pointshapes[i] <- 1
         palpha[i] <- "ns"
-      }
-      else if (pv[i]>=0.01 && pv[i]<0.05) {
-        if (showPValueLabels) {
-          ps[i] <- paste(ps[i], "*")
-        }
+      } else if (pv[i] >= 0.01 && pv[i] < 0.05) {
+        if (showPValueLabels) ps[i] <- paste(ps[i], "*")
         pointshapes[i] <- 2
-      }
-      else if (pv[i]>=0.001 && pv[i]<0.01) {
-        if (showPValueLabels) {
-          ps[i] <- paste(ps[i], "**")
-        }
+      } else if (pv[i] >= 0.001 && pv[i] < 0.01) {
+        if (showPValueLabels) ps[i] <- paste(ps[i], "**")
         pointshapes[i] <- 3
-      }
-      else {
-        if (showPValueLabels) {
-          ps[i] <- paste(ps[i], "***")
-        }
+      } else {
+        if (showPValueLabels) ps[i] <- paste(ps[i], "***")
         pointshapes[i] <- 4
       }
     }  
@@ -270,23 +265,19 @@ sjp.glmm <- function(...,
     if (is.null(axisLabels.y)) {
       axisLabels.y <- row.names(odds)
       #remove intercept from labels
-      if (!showIntercept) {
-        axisLabels.y <- axisLabels.y[-1]
-      }
+      if (!showIntercept) axisLabels.y <- axisLabels.y[-1]
     }
     # ----------------------------
     # bind p-values to data frame
     # ----------------------------
-    odds <- cbind(odds, ps, palpha, pointshapes, fitcnt)
+    odds <- data.frame(odds, ps, palpha, pointshapes, fitcnt)
     # set column names
-    names(odds) <- c("OR", "lower", "upper", "p", "pa", "shape", "grp")
+    colnames(odds) <- c("OR", "lower", "upper", "p", "pa", "shape", "grp")
     # set x-position
-    odds$xpos <- cbind(c(nrow(odds):1))
+    odds$xpos <- c(nrow(odds):1)
     odds$xpos <- as.factor(odds$xpos)
     #remove intercept from df
-    if (!showIntercept) {
-      odds <- odds[-1,]
-    }
+    if (!showIntercept) odds <- odds[-1, ]
     # add data frame to final data frame
     finalodds <- rbind(finalodds, odds)
   }
@@ -306,20 +297,20 @@ sjp.glmm <- function(...,
     # we have confindence intervals displayed, so
     # the range corresponds to the boundaries given by
     # the CI's
-    upper_lim <- (ceiling(10*max(finalodds$upper))) / 10
-    lower_lim <- (floor(10*min(finalodds$lower))) / 10
+    upper_lim <- ceiling(10 * max(finalodds$upper)) / 10
+    lower_lim <- floor(10 * min(finalodds$lower)) / 10
+    # avoid zero or NA axis limit!
+    if (is.na(upper_lim)) upper_lim <- ceiling(10 * max(na.omit(finalodds$upper))) / 10
+    if (lower_lim == 0 || is.na(lower_lim)) lower_lim <- 0.01
     # if we show p value labels, increase upper
     # limit of x axis, so labels are plotted inside
     # diagram range
-    if (showValueLabels || showPValueLabels) {
-      upper_lim <- upper_lim + 0.1
-    }
+    if (showValueLabels || showPValueLabels) upper_lim <- upper_lim + 0.1
     # give warnings when auto-limits are very low/high
     if ((lower_lim < 0.1) || (upper_lim > 100)) {
       warning("Exp. coefficients and/or exp. confidence intervals may be out of printable bounds. Consider using \"axisLimits\" parameter!")
     }
-  }
-  else {
+  } else {
     # Here we have user defind axis range
     lower_lim <- axisLimits[1]
     upper_lim <- axisLimits[2]
@@ -328,17 +319,15 @@ sjp.glmm <- function(...,
   # Define axis ticks, i.e. at which position we have grid
   # bars.
   # --------------------------------------------------------
-  ticks<-c(seq(lower_lim, upper_lim, by=gridBreaksAt))
-  if (!showAxisLabels.y) {
-    axisLabels.y <- c("")
-  }
+  ticks <- c(seq(lower_lim, upper_lim, by = gridBreaksAt))
+  if (!showAxisLabels.y) axisLabels.y <- c("")
   # --------------------------------------------------------
   # body of plot
   # --------------------------------------------------------
   # The order of aesthetics matters in terms of ordering the error bars!
   # Using alpha-aes before colour would order error-bars according to
   # alpha-level instead of colour-aes.
-  plotHeader <- ggplot(finalodds, aes(y=OR, x=xpos, colour=grp, alpha=pa))
+  plotHeader <- ggplot(finalodds, aes(y = OR, x = xpos, colour = grp, alpha = pa))
   # --------------------------------------------------------
   # start with dot-plotting here
   # first check, whether user wants different shapes for
@@ -352,28 +341,41 @@ sjp.glmm <- function(...,
       # The order of aesthetics matters in terms of ordering the error bars!
       # Using shape before colour would order points according to shapes instead
       # of colour-aes.
-      geom_point(aes(y=OR, x=xpos, colour=grp, shape=shape), size=geom.size, position=position_dodge(-geom.spacing)) +
+      geom_point(aes(shape = shape), 
+                 size = geom.size, 
+                 position = position_dodge(-geom.spacing)) +
       # and use a shape scale, in order to have a legend
-      scale_shape_manual(values=c(1,16,17,15), labels=c("n.s.", "*", "**", "***"))
-  }
-  else {
+      scale_shape_manual(values = c(1, 16, 17, 15), 
+                         labels = c("n.s.", "*", "**", "***"))
+  } else {
     plotHeader <- plotHeader +
-      geom_point(size=geom.size, position=position_dodge(-geom.spacing))
+      geom_point(size = geom.size, 
+                 position = position_dodge(-geom.spacing))
   }
   # --------------------------------------------------------
   # continue with errorbars, p-value-label and intercept line
   # --------------------------------------------------------
   plotHeader <- plotHeader +
     # print confidence intervalls (error bars)
-    geom_errorbar(aes(ymin=lower, ymax=upper), width=0, position=position_dodge(-geom.spacing)) +
+    geom_errorbar(aes(ymin = lower, ymax = upper), 
+                  width = 0, 
+                  position = position_dodge(-geom.spacing)) +
     # print value labels and p-values
-    geom_text(aes(label=p, y=upper), position=position_dodge(width=-geom.spacing), hjust=-0.1) +
+    geom_text(aes(label = p, y = upper), 
+              position = position_dodge(width = -geom.spacing), 
+              hjust = -0.1) +
     # Intercept-line
-    geom_hline(yintercept=1, linetype=interceptLineType, color=interceptLineColor) +
-    labs(title=title, x=NULL, y=axisTitle.x, shape=legendPValTitle, colour=legendDepVarTitle) +
-    scale_x_discrete(labels=axisLabels.y) +
+    geom_hline(yintercept = 1, 
+               linetype = interceptLineType, 
+               colour = interceptLineColor) +
+    labs(title = title, 
+         x = NULL, 
+         y = axisTitle.x, 
+         shape = legendPValTitle, 
+         colour = legendDepVarTitle) +
+    scale_x_discrete(labels = axisLabels.y) +
     # use transparancy if requested, but hide legend
-    scale_alpha_manual(values=c(nsAlpha,1.0), guide="none")
+    scale_alpha_manual(values = c(nsAlpha, 1.0), guide = "none")
   # --------------------------------------------------------
   # create pretty breaks for log-scale
   # --------------------------------------------------------
@@ -387,8 +389,7 @@ sjp.glmm <- function(...,
                          limits = c(lower_lim, upper_lim), 
                          breaks = base_breaks(upper_lim),
                          labels = prettyNum)
-  }
-  else {
+  } else {
     plotHeader <- plotHeader +
       # logarithmic scale for odds
       # logarithmic scale for odds
@@ -399,17 +400,16 @@ sjp.glmm <- function(...,
   # --------------------------------------------------------
   # flip coordinates?
   # --------------------------------------------------------
-  if (coord.flip)  {
-    plotHeader <- plotHeader +
-      coord_flip()
-  }
-  if (facet.grid) {
-    plotHeader <- plotHeader + facet_grid(.~grp)
-  }  
+  if (coord.flip)  plotHeader <- plotHeader + coord_flip()
+  if (facet.grid) plotHeader <- plotHeader + facet_grid(. ~ grp)
   # ---------------------------------------------------------
   # set geom colors
   # ---------------------------------------------------------
-  plotHeader <- sj.setGeomColors(plotHeader, geom.colors, length(labelDependentVariables), ifelse(hideLegend==TRUE, FALSE, TRUE), labelDependentVariables)
+  plotHeader <- sj.setGeomColors(plotHeader, 
+                                 geom.colors, 
+                                 length(labelDependentVariables), 
+                                 ifelse(hideLegend == TRUE, FALSE, TRUE), 
+                                 labelDependentVariables)
   # ---------------------------------------------------------
   # Check whether ggplot object should be returned or plotted
   # ---------------------------------------------------------
