@@ -1,18 +1,16 @@
 #' @title Plot PCA results
 #' @name sjp.pca
 #' 
-#' @description Performes a principle component analysis on a data frame or matrix and plots 
-#'                the factor solution as ellipses or tiles. \cr \cr In case a data frame is used as 
-#'                parameter, the cronbach's alpha value for each factor scale will be calculated,
-#'                i.e. all variables with the highest loading for a factor are taken for the
-#'                reliability test. The result is an alpha value for each factor dimension.
+#' @description Performes a principle component analysis on a data frame or matrix (with
+#'                varimax rotation) and plots the factor solution as ellipses or tiles. \cr \cr 
+#'                In case a data frame is used as parameter, the cronbach's alpha value for 
+#'                each factor scale will be calculated, i.e. all variables with the highest 
+#'                loading for a factor are taken for the reliability test. The result is 
+#'                an alpha value for each factor dimension.
 #' 
 #' @seealso \itemize{
 #'            \item \href{http://www.strengejacke.de/sjPlot/sjp.pca/}{sjPlot manual: sjp.pca}
 #'            \item \code{\link{sjt.pca}}
-#'            \item \code{\link{reliab_test}}
-#'            \item \code{\link{sjt.itemanalysis}}
-#'            \item \code{\link{cronb}}
 #'            }
 #' 
 #' @param data A data frame with factors (each columns one variable) that should be used 
@@ -33,8 +31,9 @@
 #' @param axisLabels.y The item labels that are printed on the y-axis. If no item labels are
 #'          provided (default), the data frame's column names are used. Item labels must
 #'          be a string vector, e.g.: \code{axisLabels.y = c("Var 1", "Var 2", "Var 3")}.
-#' @param type Indicates whether \code{"circle"} (default) or \code{"tile"} geoms
-#'          should be used for plotting.
+#' @param type Plot type resp. geom type. May be one of following: \code{"circle"} or \code{"tile"} 
+#'          circular or tiled geoms, or \code{"bar"} for a bar plot. You may use initial letter only
+#'          for this parameter.
 #' @param geom.colors A color palette for fillng the geoms. If not specified, the diverging \code{"RdBl"} color palette
 #'          from the color brewer palettes is used, resulting in red colors for negative and blue colors
 #'          for positive factor loadings, that become lighter the weaker the loadings are. Use any
@@ -66,30 +65,60 @@
 #' 
 #' @examples
 #' # randomly create data frame with 7 items, each consisting of 4 categories
-#' likert_4 <- data.frame(sample(1:4, 500, replace = TRUE, prob = c(0.2,0.3,0.1,0.4)),
-#'                        sample(1:4, 500, replace = TRUE, prob = c(0.5,0.25,0.15,0.1)),
-#'                        sample(1:4, 500, replace = TRUE, prob = c(0.4,0.15,0.25,0.2)),
-#'                        sample(1:4, 500, replace = TRUE, prob = c(0.25,0.1,0.4,0.25)),
-#'                        sample(1:4, 500, replace = TRUE, prob = c(0.1,0.4,0.4,0.1)),
-#'                        sample(1:4, 500, replace = TRUE),
-#'                        sample(1:4, 500, replace = TRUE, prob = c(0.35,0.25,0.15,0.25)))
+#' likert_4 <- data.frame(sample(1:4, 
+#'                               500, 
+#'                               replace = TRUE, 
+#'                               prob = c(0.2, 0.3, 0.1, 0.4)),
+#'                        sample(1:4, 
+#'                               500, 
+#'                               replace = TRUE, 
+#'                               prob = c(0.5, 0.25, 0.15, 0.1)),
+#'                        sample(1:4, 
+#'                               500, 
+#'                               replace = TRUE, 
+#'                               prob = c(0.4, 0.15, 0.25, 0.2)),
+#'                        sample(1:4, 
+#'                               500, 
+#'                               replace = TRUE, 
+#'                               prob = c(0.25, 0.1, 0.4, 0.25)),
+#'                        sample(1:4, 
+#'                               500, 
+#'                               replace = TRUE, 
+#'                               prob = c(0.1, 0.4, 0.4, 0.1)),
+#'                        sample(1:4, 
+#'                               500, 
+#'                               replace = TRUE),
+#'                        sample(1:4, 
+#'                               500, 
+#'                               replace = TRUE, 
+#'                               prob = c(0.35, 0.25, 0.15, 0.25)))
 #'
 #' # Create variable labels
 #' colnames(likert_4) <- c("V1", "V2", "V3", "V4", "V5", "V6", "V7")
 #' 
 #' # plot results from PCA as square-tiled "heatmap"
-#' sjp.pca(likert_4)
+#' sjp.pca(likert_4, type = "tile")
+#' 
+#' # plot results from PCA as bars
+#' sjp.pca(likert_4, type = "bar")
 #' 
 #' # manually compute PCA
-#' pca <- prcomp(na.omit(likert_4), retx = TRUE, center = TRUE, scale. = TRUE)
+#' pca <- prcomp(na.omit(likert_4), 
+#'               retx = TRUE, 
+#'               center = TRUE, 
+#'               scale. = TRUE)
 #' # plot results from PCA as circles, including Eigenvalue-diagnostic.
 #' # note that this plot does not compute the Cronbach's Alpha
-#' sjp.pca(pca, plotEigenvalues = TRUE, type = "circle")
+#' sjp.pca(pca, 
+#'         plotEigenvalues = TRUE, 
+#'         type = "circle",
+#'         geom.size = 10)
 #' 
 #' 
 #' # -------------------------------
 #' # Data from the EUROFAMCARE sample dataset
 #' # -------------------------------
+#' library(sjmisc)
 #' data(efc)
 #' 
 #' # retrieve variable and value labels
@@ -101,16 +130,17 @@
 #' end <- which(colnames(efc) == "c90cop9")
 #'  
 #' # create data frame with COPE-index scale
-#' df <- as.data.frame(efc[,c(start:end)])
-#' colnames(df) <- varlabs[c(start:end)]
+#' mydf <- as.data.frame(efc[, c(start:end)])
+#' colnames(mydf) <- varlabs[c(start:end)]
 #' 
-#' sjp.pca(df)
+#' sjp.pca(mydf)
+#' sjp.pca(mydf, type = "tile")
 #' 
 #' # -------------------------------
 #' # auto-detection of labels
 #' # -------------------------------
 #' efc <- set_var_labels(efc, varlabs)
-#' sjp.pca(efc[, c(start:end)])
+#' sjp.pca(efc[, c(start:end)], type = "circle", geom.size = 10)
 #' 
 #' 
 #' @import ggplot2
@@ -124,8 +154,8 @@ sjp.pca <- function(data,
                     digits=2,
                     title=NULL,
                     axisLabels.y=NULL,
-                    type="tile",
-                    geom.size=10,
+                    type="b",
+                    geom.size=.6,
                     geom.colors="RdBu",                    
                     breakTitleAt=50, 
                     breakLabelsAt=20, 
@@ -133,18 +163,23 @@ sjp.pca <- function(data,
                     showCronbachsAlpha=TRUE,
                     printPlot=TRUE) {
   # --------------------------------------------------------
+  # check parameters
+  # --------------------------------------------------------
+  if (type == "circles" || type == "circle") type <- "c"
+  if (type == "tiles" || type == "tile") type <- "t"
+  if (type == "bars" || type == "bar") type <- "b"
+  # --------------------------------------------------------
   # try to automatically set labels is not passed as parameter
   # --------------------------------------------------------
   if (is.null(axisLabels.y) && is.data.frame(data)) {
     # if yes, iterate each variable
     for (i in 1:ncol(data)) {
       # retrieve variable name attribute
-      vn <- autoSetVariableLabels(data[, i])
+      vn <- sjmisc:::autoSetVariableLabels(data[, i])
       # if variable has attribute, add to variableLabel list
       if (!is.null(vn)) {
         axisLabels.y <- c(axisLabels.y, vn)
-      }
-      else {
+      } else {
         # else break out of loop
         axisLabels.y <- NULL
         break
@@ -155,9 +190,8 @@ sjp.pca <- function(data,
   # set color palette
   # ----------------------------  
   if (is.brewer.pal(geom.colors[1])) {
-    geom.colors <- scales::brewer_pal(palette=geom.colors[1])(5)
-  }
-  else if (geom.colors[1] == "gs") {
+    geom.colors <- scales::brewer_pal(palette = geom.colors[1])(5)
+  } else if (geom.colors[1] == "gs") {
     geom.colors <- scales::grey_pal()(5)
   }
   # ----------------------------
@@ -167,17 +201,14 @@ sjp.pca <- function(data,
   if (class(data) == "prcomp") {
     pcadata <- data
     dataframeparam <- FALSE
-  }
-  else {
+  } else {
     pcadata <- prcomp(na.omit(data), retx = TRUE, center = TRUE, scale. = TRUE)
     dataframeparam <- TRUE
   }
   # --------------------------------------------------------
   # unlist labels
   # --------------------------------------------------------
-  if (!is.null(axisLabels.y) && is.list(axisLabels.y)) {
-    axisLabels.y <- unlistlabels(axisLabels.y)
-  }
+  if (!is.null(axisLabels.y) && is.list(axisLabels.y)) axisLabels.y <- unlistlabels(axisLabels.y)
   # ----------------------------
   # calculate eigenvalues
   # ----------------------------
@@ -200,7 +231,12 @@ sjp.pca <- function(data,
         geom_line() + geom_point() +
         geom_hline(y = 1, linetype = 2, colour = "grey50") +
         # print best number of factors according to eigen value
-        annotate("text", label = sprintf("Factors: %i", pcadata.kaiser), x = Inf, y = Inf, vjust = 2, hjust = 1.2) +
+        annotate("text", 
+                 label = sprintf("Factors: %i", pcadata.kaiser), 
+                 x = Inf, 
+                 y = Inf, 
+                 vjust = 2, 
+                 hjust = 1.2) +
         scale_x_continuous(breaks = c(seq(1, nrow(mydat), by = 2))) +
         labs(title = NULL, y = "Eigenvalue", x = "Number of factors")
     plot(eigenplot)
@@ -215,9 +251,7 @@ sjp.pca <- function(data,
   # varimax rotation, retrieve factor loadings
   # --------------------------------------------------------
   # check for predefined number of factors
-  if (!is.null(numberOfFactors) && is.numeric(numberOfFactors)) {
-    pcadata.kaiser <- numberOfFactors
-  }
+  if (!is.null(numberOfFactors) && is.numeric(numberOfFactors)) pcadata.kaiser <- numberOfFactors
   pcadata.varim <- varimaxrota(pcadata, pcadata.kaiser)
   # pcadata.varim = varimax(loadings(pcadata))
   # create data frame with factor loadings
@@ -227,20 +261,14 @@ sjp.pca <- function(data,
   # check if user defined labels have been supplied
   # if not, use variable names from data frame
   # ----------------------------
-  if (is.null(axisLabels.y)) {
-    axisLabels.y <- row.names(df)
-  }
+  if (is.null(axisLabels.y)) axisLabels.y <- row.names(df)
   # ----------------------------
   # Prepare length of title and labels
   # ----------------------------
   # check length of diagram title and split longer string at into new lines
-  if (!is.null(title)) {
-    title <- word_wrap(title, breakTitleAt)
-  }
+  if (!is.null(title)) title <- sjmisc::word_wrap(title, breakTitleAt)
   # check length of x-axis-labels and split longer strings at into new lines
-  if (!is.null(axisLabels.y)) {
-    axisLabels.y <- word_wrap(axisLabels.y, breakLabelsAt)
-  }
+  if (!is.null(axisLabels.y)) axisLabels.y <- sjmisc::word_wrap(axisLabels.y, breakLabelsAt)
   # --------------------------------------------------------
   # this function checks which items have unclear factor loadings,
   # i.e. which items do not strongly load on a single factor but
@@ -259,7 +287,7 @@ sjp.pca <- function(data,
       # retrieve 2. highest loading
       max2load <- sort(rowval, TRUE)[2]
       # check difference between both
-      if (abs(maxload-max2load) < factorLoadingTolerance) {
+      if (abs(maxload - max2load) < factorLoadingTolerance) {
         # if difference is below the tolerance,
         # remeber row-ID so we can remove that items
         # for further PCA with updated data frame
@@ -304,7 +332,7 @@ sjp.pca <- function(data,
     for (n in 1:length(unique(itemloadings))) {
       # calculate cronbach's alpha for those cases that all have the
       # highest loading on the same factor
-      cbv <- as.data.frame(rbind(cbv, cbind(nr = n, cronb(na.omit(dataframe[, which(itemloadings == n)])))))
+      cbv <- as.data.frame(rbind(cbv, cbind(nr = n, sjmisc::cronb(na.omit(dataframe[, which(itemloadings == n)])))))
     }
     # just for vertical position adjustment when we print the alpha values
     vpos <- rep(c(-0.25, -1), nrow(cbv))
@@ -321,8 +349,7 @@ sjp.pca <- function(data,
   if (dataframeparam) {
     # get alpha values
     alphaValues <- getCronbach(data, getItemLoadings(df))
-  }
-  else {
+  } else {
     message("Cronbach's Alpha can only be calculated when having a data frame with each component / variable as column.")
     showCronbachsAlpha <- FALSE
   }
@@ -339,44 +366,74 @@ sjp.pca <- function(data,
   df <- cbind(df, ypos = c(1:nrow(pcadata.varim$loadings)), psize = c(exp(abs(df$value)) * geom.size))
   if (!showValueLabels) {
     valueLabels <- c("")
-  }
-  else {
+  } else {
     valueLabels <- sprintf("%.*f", digits, df$value)
   }
   # --------------------------------------------------------
   # start with base plot object here
   # --------------------------------------------------------
-  heatmap <- ggplot(data = df, aes(x = xpos, y = ypos, fill = value))
+  if (type == "b") {
+    heatmap <- ggplot(df, aes(x = rev(factor(ypos)), 
+                              y = abs(value), 
+                              fill = value))
+  } else {
+    heatmap <- ggplot(data = df, aes(x = xpos, 
+                                     y = ypos, 
+                                     fill = value))
+  }
   # --------------------------------------------------------
   # determine the geom type, either points when "type" is "circles"
   # --------------------------------------------------------
-  if (type == "circle") {
+  if (type == "c") {
     geo <- geom_point(shape = 21, size = df$psize)
-  }
-  # --------------------------------------------------------
-  # or boxes / tiles when "type" is "tile"
-  # --------------------------------------------------------
-  else {
+  } else if (type == "t") {
+    # ----------------------------------------
+    # or boxes / tiles when "type" is "tile"
+    # ----------------------------------------
     geo <- geom_tile()
+  } else {
+    # ----------
+    # or bars
+    # ----------
+    geo <- geom_bar(stat = "identity", width = geom.size)
   }
   heatmap <- heatmap +
     geo +
-    scale_y_reverse(breaks = c(seq(1, length(axisLabels.y), by = 1)), labels = axisLabels.y) +
     # --------------------------------------------------------
-    # fill gradient colour from distinct color brewer palette. negative correlations are dark
-    # red, positive corr. are dark blue, and they become lighter the closer they are to a
-    # correlation coefficient of zero
+    # fill gradient colour from distinct color brewer palette. 
+    # negative correlations are dark red, positive corr. are dark blue, 
+    # and they become lighter the closer they are to a correlation 
+    # coefficient of zero
     # --------------------------------------------------------
-    scale_fill_gradientn(colours = geom.colors, limits = c(-1,1)) +
-    geom_text(label = valueLabels) +
+    scale_fill_gradientn(colours = geom.colors, limits = c(-1, 1)) +
     labs(title = title, x = NULL, y = NULL, fill = NULL) +
     guides(fill = FALSE)
   # --------------------------------------------------------
-  # show cronbach's alpha value for each scale 
+  # facet bars, and flip coordinates
   # --------------------------------------------------------
-  if (showCronbachsAlpha) {
-    heatmap <- heatmap +
-      annotate("text", x = alphaValues$nr, y = Inf, parse = TRUE, label = sprintf("alpha == %.*f", digits, alphaValues$alpha), vjust = -0.5)
+  if (type == "b") {
+    heatmap <- heatmap + 
+      scale_x_discrete(labels = axisLabels.y) +
+      scale_y_continuous(limits = c(0, 1)) +
+      facet_grid(~ xpos) +
+      coord_flip()
+  } else {
+    heatmap <- heatmap + 
+      geom_text(label = valueLabels) +
+      scale_y_reverse(breaks = c(seq(1, length(axisLabels.y), by = 1)), 
+                      labels = axisLabels.y)
+    # --------------------------------------------------------
+    # show cronbach's alpha value for each scale 
+    # --------------------------------------------------------
+    if (showCronbachsAlpha) {
+      heatmap <- heatmap +
+        annotate("text", 
+                 x = alphaValues$nr, 
+                 y = Inf, 
+                 parse = TRUE, 
+                 label = sprintf("alpha == %.*f", digits, alphaValues$alpha), 
+                 vjust = -0.5)
+    }
   }
   # --------------------------------------------------------
   # print plot
@@ -395,8 +452,7 @@ sjp.pca <- function(data,
     if (!is.null(removableItems)) {
       message(colnames(data)[removableItems])
       remdf <- data[,c(-removableItems)]
-    }
-    else {
+    } else {
       message("none.")
     }
   }
